@@ -348,8 +348,9 @@ class TestJsonnetAction:
         "_register_binary",
         "_register_binary_with_one_option",
         # "_register_binary_with_multiple_options", TODO handle (options)(c1)
+        "_shared_volumes"
     ])
-    def test_docker_compose_register_binary(self, project_loader, variant):
+    def test_docker_compose_variants(self, project_loader, variant):
         project_loader("docker_compose" + variant)
 
         features.register(CoreFeature())
